
# Slot: has count




URI: [biolink:variant_to_population_association_has_count](https://w3id.org/biolink/vocab/variant_to_population_association_has_count)

## Domain and Range

[VariantToPopulationAssociation](VariantToPopulationAssociation.md) ->  <sub>OPT</sub> [Integer](Integer.md)

## Parents

 *  is_a: [has count](has_count.md)

## Children


## Used by

 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
